﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;

public partial class _RadGridDefault : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Session["GridData"] == null)
        {
            Session["GridData"] = GenerateData();
        }
    }

    protected void RadGrid1_NeedDataSource(object sender, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        RadGrid1.DataSource = PopulateGrid;
    }

    public DataTable PopulateGrid
    {
        get
        {
            DataTable data = (DataTable)Session["GridData"];

            return data;
        }

        set
        {
            Session["GridData"] = GenerateData();
        }
    }

    public DataTable GenerateData()
    {
        DataTable data = new DataTable();

        data.Columns.Add("ID", typeof(int));
        data.Columns.Add("Name");
        data.Columns.Add("Description");

        for (int i = 1; i < 31; i++)
        {
            data.Rows.Add(i, "Name" + (i % 5).ToString(), "Description" + i.ToString());
        }

        return data;
    }



    protected void RadGrid1_ItemCommand(object source, GridCommandEventArgs e)
    {
        DataTable selectedItems;

        if (Session["selectedItems"] == null)
        {
            selectedItems = new DataTable();

            selectedItems.Columns.Add("ID", typeof(int));
            selectedItems.Columns.Add("Name");
            selectedItems.Columns.Add("Description");
        }
        else
        {
            selectedItems = (DataTable)Session["selectedItems"];
        }

        if (e.CommandName == RadGrid.SelectCommandName && e.Item is GridDataItem)
        {
            GridDataItem dataItem = (GridDataItem)e.Item;

            if (selectedItems.Select("ID = " + dataItem["ID"].Text).Length != 0)
            {
                return;
            }

            DataRow row = selectedItems.NewRow();

            row["ID"] = (dataItem["ID"]).Text;
            row["Name"] = (dataItem["Name"]).Text;
            row["Description"] = (dataItem["Description"]).Text;

            selectedItems.Rows.Add(row);

            Session["selectedItems"] = selectedItems;
        }
        if (e.CommandName == RadGrid.DeselectCommandName && e.Item is GridDataItem)
        {
            GridDataItem dataItem = (GridDataItem)e.Item;
            DataRow[] row = selectedItems.Select("ID = " + dataItem["ID"].Text);

            if (row.Length == 0)
            {
                return;
            }

            row[0]["ID"] = (dataItem["ID"]).Text;
            row[0]["Name"] = (dataItem["Name"]).Text;
            row[0]["Description"] = (dataItem["Description"]).Text;

            selectedItems.Rows.Remove(row[0]);

            Session["selectedItems"] = selectedItems;
        }

        if (e.CommandName == "ShowSelected")
        {
            DataView dv = ((DataTable)Session["selectedItems"]).DefaultView;
            
            // sort selected items by id
            dv.Sort = "ID";
            DataTable sortedDT = dv.ToTable();


            RadGrid1.DataSource = sortedDT;
            RadGrid1.Rebind();
        }

        if (e.CommandName == "ShowAll")
        {
            Session["selectedItems"] = null;
            RadGrid1.DataSource = PopulateGrid;
            RadGrid1.Rebind();
        }
    }

    protected void RadGrid1_PreRender(object sender, EventArgs e)
    {
        if (Session["selectedItems"] != null)
        {
            DataTable selectedItems = (DataTable)Session["selectedItems"];

            foreach (DataRow row in selectedItems.Rows)
            {
                foreach (GridItem item in RadGrid1.MasterTableView.Items)
                {
                    if (item is GridDataItem)
                    {
                        GridDataItem dataItem = item as GridDataItem;

                        if (row["ID"].ToString() == dataItem.OwnerTableView.DataKeyValues[dataItem.ItemIndex]["ID"].ToString())
                        {
                            dataItem.Selected = true;
                            break;
                        }
                    }
                }
            }
        }
    }
}